/*******************************************************************************
* File Name: LED_isr_Off.c  
* Version 1.70
*
*  Description:
*   API for controlling the state of an interrupt.
*
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/


#include <cydevice_trm.h>
#include <CyLib.h>
#include <LED_isr_Off.h>

#if !defined(LED_isr_Off__REMOVED) /* Check for removal by optimization */

/*******************************************************************************
*  Place your includes, defines and code here 
********************************************************************************/
    #include<LED_isr_On.h> 
    #include<LED_Control.h>
/* `#START LED_isr_Off_intc` */

/* `#END` */

#ifndef CYINT_IRQ_BASE
#define CYINT_IRQ_BASE      16
#endif /* CYINT_IRQ_BASE */
#ifndef CYINT_VECT_TABLE
#define CYINT_VECT_TABLE    ((cyisraddress **) CYREG_NVIC_VECT_OFFSET)
#endif /* CYINT_VECT_TABLE */

/* Declared in startup, used to set unused interrupts to. */
CY_ISR_PROTO(IntDefaultHandler);


/*******************************************************************************
* Function Name: LED_isr_Off_Start
********************************************************************************
*
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   None
*
* Return:
*   None
*
*******************************************************************************/
void LED_isr_Off_Start(void)
{
    /* For all we know the interrupt is active. */
    LED_isr_Off_Disable();

    /* Set the ISR to point to the LED_isr_Off Interrupt. */
    LED_isr_Off_SetVector(&LED_isr_Off_Interrupt);

    /* Set the priority. */
    LED_isr_Off_SetPriority((uint8)LED_isr_Off_INTC_PRIOR_NUMBER);

    /* Enable it. */
    LED_isr_Off_Enable();
}


/*******************************************************************************
* Function Name: LED_isr_Off_StartEx
********************************************************************************
*
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   address: Address of the ISR to set in the interrupt vector table.
*
* Return:
*   None
*
*******************************************************************************/
void LED_isr_Off_StartEx(cyisraddress address)
{
    /* For all we know the interrupt is active. */
    LED_isr_Off_Disable();

    /* Set the ISR to point to the LED_isr_Off Interrupt. */
    LED_isr_Off_SetVector(address);

    /* Set the priority. */
    LED_isr_Off_SetPriority((uint8)LED_isr_Off_INTC_PRIOR_NUMBER);

    /* Enable it. */
    LED_isr_Off_Enable();
}


/*******************************************************************************
* Function Name: LED_isr_Off_Stop
********************************************************************************
*
* Summary:
*   Disables and removes the interrupt.
*
* Parameters:  
*
* Return:
*   None
*
*******************************************************************************/
void LED_isr_Off_Stop(void)
{
    /* Disable this interrupt. */
    LED_isr_Off_Disable();

    /* Set the ISR to point to the passive one. */
    LED_isr_Off_SetVector(&IntDefaultHandler);
}


/*******************************************************************************
* Function Name: LED_isr_Off_Interrupt
********************************************************************************
*
* Summary:
*   The default Interrupt Service Routine for LED_isr_Off.
*
*   Add custom code between the coments to keep the next version of this file
*   from over writting your code.
*
* Parameters:  
*
* Return:
*   None
*
*******************************************************************************/
CY_ISR(LED_isr_Off_Interrupt)
{
    /*  Place your Interrupt code here. */
    LED_Control_Write(00000000); 
    /* `#START LED_isr_Off_Interrupt` */

    /* `#END` */
}


/*******************************************************************************
* Function Name: LED_isr_Off_SetVector
********************************************************************************
*
* Summary:
*   Change the ISR vector for the Interrupt. Note calling LED_isr_Off_Start
*   will override any effect this method would have had. To set the vector 
*   before the component has been started use LED_isr_Off_StartEx instead.
*
* Parameters:
*   address: Address of the ISR to set in the interrupt vector table.
*
* Return:
*   None
*
*******************************************************************************/
void LED_isr_Off_SetVector(cyisraddress address)
{
    cyisraddress * ramVectorTable;

    ramVectorTable = (cyisraddress *) *CYINT_VECT_TABLE;

    ramVectorTable[CYINT_IRQ_BASE + (uint32)LED_isr_Off__INTC_NUMBER] = address;
}


/*******************************************************************************
* Function Name: LED_isr_Off_GetVector
********************************************************************************
*
* Summary:
*   Gets the "address" of the current ISR vector for the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   Address of the ISR in the interrupt vector table.
*
*******************************************************************************/
cyisraddress LED_isr_Off_GetVector(void)
{
    cyisraddress * ramVectorTable;

    ramVectorTable = (cyisraddress *) *CYINT_VECT_TABLE;

    return ramVectorTable[CYINT_IRQ_BASE + (uint32)LED_isr_Off__INTC_NUMBER];
}


/*******************************************************************************
* Function Name: LED_isr_Off_SetPriority
********************************************************************************
*
* Summary:
*   Sets the Priority of the Interrupt. Note calling LED_isr_Off_Start
*   or LED_isr_Off_StartEx will override any effect this method 
*   would have had. This method should only be called after 
*   LED_isr_Off_Start or LED_isr_Off_StartEx has been called. To set 
*   the initial priority for the component use the cydwr file in the tool.
*
* Parameters:
*   priority: Priority of the interrupt. 0 - 7, 0 being the highest.
*
* Return:
*   None
*
*******************************************************************************/
void LED_isr_Off_SetPriority(uint8 priority)
{
    *LED_isr_Off_INTC_PRIOR = priority << 5;
}


/*******************************************************************************
* Function Name: LED_isr_Off_GetPriority
********************************************************************************
*
* Summary:
*   Gets the Priority of the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   Priority of the interrupt. 0 - 7, 0 being the highest.
*
*******************************************************************************/
uint8 LED_isr_Off_GetPriority(void)
{
    uint8 priority;


    priority = *LED_isr_Off_INTC_PRIOR >> 5;

    return priority;
}


/*******************************************************************************
* Function Name: LED_isr_Off_Enable
********************************************************************************
*
* Summary:
*   Enables the interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void LED_isr_Off_Enable(void)
{
    /* Enable the general interrupt. */
    *LED_isr_Off_INTC_SET_EN = LED_isr_Off__INTC_MASK;
}


/*******************************************************************************
* Function Name: LED_isr_Off_GetState
********************************************************************************
*
* Summary:
*   Gets the state (enabled, disabled) of the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   1 if enabled, 0 if disabled.
*
*******************************************************************************/
uint8 LED_isr_Off_GetState(void)
{
    /* Get the state of the general interrupt. */
    return ((*LED_isr_Off_INTC_SET_EN & (uint32)LED_isr_Off__INTC_MASK) != 0u) ? 1u:0u;
}


/*******************************************************************************
* Function Name: LED_isr_Off_Disable
********************************************************************************
*
* Summary:
*   Disables the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void LED_isr_Off_Disable(void)
{
    /* Disable the general interrupt. */
    *LED_isr_Off_INTC_CLR_EN = LED_isr_Off__INTC_MASK;
}


/*******************************************************************************
* Function Name: LED_isr_Off_SetPending
********************************************************************************
*
* Summary:
*   Causes the Interrupt to enter the pending state, a software method of
*   generating the interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void LED_isr_Off_SetPending(void)
{
    *LED_isr_Off_INTC_SET_PD = LED_isr_Off__INTC_MASK;
}


/*******************************************************************************
* Function Name: LED_isr_Off_ClearPending
********************************************************************************
*
* Summary:
*   Clears a pending interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void LED_isr_Off_ClearPending(void)
{
    *LED_isr_Off_INTC_CLR_PD = LED_isr_Off__INTC_MASK;
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
